﻿; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = some_name
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /DB, a   ;hold down-back while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their command detection.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands examples are given below.
;
; [Command] ;Quarter circle forward + x
; name = "QCF_x"
; command = ~D, DF, F, x
;
; [Command] ;Half circle back + a
; name = "HCB_a"
; command = ~F, DF, D, DB, B, a
;
; [Command] ;Two quarter circles forward + y
; name = "2QCF_y"
; command = ~D, DF, F, D, DF, F, y
;
; [Command] ;Tap b rapidly
; name = "5b"
; command = b, b, b, b, b
; time = 30
;
; [Command] ;Charge back, then forward + z
; name = "charge_B_F_z"
; command = ~60$B, F, z
; time = 10
; 
; [Command] ;Charge down, then up + c
; name = "charge_D_U_c"
; command = ~60$D, U, c
; time = 10
; 

;-| Button Remapping |-----------------------------------------------------
; This section lets you remap the player's buttons (to easily change the
; button configuration). The format is:
;   old_button = new_button
; If new_button is left blank, the button cannot be pressed.
[Remap]
x = x
y = y
z = z
a = a
b = b
c = c
s = s

;-| Default Values |-------------------------------------------------------
[Defaults]
; Default value for the "time" parameter of a Command. Minimum 1.
command.time = 30

; Default value for the "buffer.time" parameter of a Command. Minimum 1,
; maximum 30.
command.buffer.time = 1

;-| Aternate State Motions |-----------------------------------------------

;-| Super Attack Motions |-------------------------------------------------

[Command]
name = "Hypercane_3-Pack"
command = ~F, B, DB, D, DF, F, y
time = 30

[Command]
name = "Atomic_Fireball_-_QP"
command = ~D, DF, F, D, DF, F, x
time = 30

[Command]
name = "Atomic_Fireball_-_HP"
command = ~D, DF, F, D, DF, F, y
time = 30

[Command]
name = "Twizzler_Downpour"
command = ~D, DB, B, D, DB, B, b
time = 30

[Command]
name = "Jawbreaker_Jamboree"
command = ~D, DB, B, DB, D, DF, F, x+y
time = 30

;-| EX Attack Motions |-----------------------------------------------

[Command]
name = "Pez_Machine-Gun_-_EX"
command = ~D, DF, F, x+y
time = 30

[Command]
name = "Sure_You_Cane_-_EX"
command = ~F, D, DF, x+y
time = 30

;-| Special Attack Motions |-----------------------------------------------

[Command]
name = "Pez_Machine-Gun_-_QP"
command = ~D, DF, F, x
time = 30

[Command]
name = "Pez_Machine-Gun_-_HP"
command = ~D, DF, F, y
time = 30

[Command]
name = "Lemon_Warhead_-_QP"
command = ~D, DB, B, x
time = 30

[Command]
name = "Lemon_Warhead_-_HP"
command = ~D, DB, B, y
time = 30

[Command]
name = "Sure_You_Cane_-_QP"
command = ~F, D, DF, x
time = 30

[Command]
name = "Sure_You_Cane_-_HP"
command = ~F, D, DF, y
time = 30

[Command]
name = "Pixie_Stick_Stunner"
command = ~B, DB, D, DF, F, a
time = 30

;-| Special Technique Motions |--------------------------------------------

;-| Double Tap |-----------------------------------------------------------

[Command]
name = "FF"     ;Required (do not remove)
command = F, F
time = 10

[Command]
name = "BB"     ;Required (do not remove)
command = B, B
time = 10

;-| 2/3 Button Combination |-----------------------------------------------

[Command]
name = "recovery" ;Required (do not remove)
command = x+y
time = 1

[Command]
name = "recovery"
command = y+z
time = 1

[Command]
name = "recovery"
command = x+z
time = 1

[Command]
name = "recovery"
command = a+b
time = 1

[Command]
name = "recovery"
command = b+c
time = 1

[Command]
name = "recovery"
command = a+c
time = 1

;-| Dir + Button |---------------------------------------------------------

[Command]
name = "back_x"
command = /$B,x
time = 1

[Command]
name = "back_y"
command = /$B,y
time = 1

[Command]
name = "back_z"
command = /$B,z
time = 1

[Command]
name = "down_x"
command = /$D,x
time = 1

[Command]
name = "down_y"
command = /$D,y
time = 1

[Command]
name = "down_z"
command = /$D,z
time = 1

[Command]
name = "fwd_x"
command = /$F,x
time = 1

[Command]
name = "fwd_y"
command = /$F,y
time = 1

[Command]
name = "fwd_z"
command = /$F,z
time = 1

[Command]
name = "up_x"
command = /$U,x
time = 1

[Command]
name = "up_y"
command = /$U,y
time = 1

[Command]
name = "up_z"
command = /$U,z
time = 1

[Command]
name = "back_a"
command = /$B,a
time = 1

[Command]
name = "back_b"
command = /$B,b
time = 1

[Command]
name = "back_c"
command = /$B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "fwd_a"
command = /$F,a
time = 1

[Command]
name = "fwd_b"
command = /$F,b
time = 1

[Command]
name = "fwd_c"
command = /$F,c
time = 1

[Command]
name = "up_a"
command = /$U,a
time = 1

[Command]
name = "up_b"
command = /$U,b
time = 1

[Command]
name = "up_c"
command = /$U,c
time = 1

;-| Single Button |---------------------------------------------------------

[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

[Command]
name = "s"
command = s
time = 1

;-| Single Dir |------------------------------------------------------------

[Command]
name = "fwd" ;Required (do not remove)
command = $F
time = 1

[Command]
name = "downfwd"
command = $DF
time = 1

[Command]
name = "down" ;Required (do not remove)
command = $D
time = 1

[Command]
name = "downback"
command = $DB
time = 1

[Command]
name = "back" ;Required (do not remove)
command = $B
time = 1

[Command]
name = "upback"
command = $UB
time = 1

[Command]
name = "up" ;Required (do not remove)
command = $U
time = 1

[Command]
name = "upfwd"
command = $UF
time = 1

;-| Hold Button |--------------------------------------------------------------

[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_z"
command = /z
time = 1

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

[Command]
name = "hold_c"
command = /c
time = 1

[Command]
name = "hold_s"
command = /s
time = 1

;-| Hold Dir |--------------------------------------------------------------

[Command]
name = "holdfwd" ;Required (do not remove)
command = /$F
time = 1

[Command]
name = "holddownfwd"
command = /$DF
time = 1

[Command]
name = "holddown" ;Required (do not remove)
command = /$D
time = 1

[Command]
name = "holddownback"
command = /$DB
time = 1

[Command]
name = "holdback" ;Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdupback"
command = /$UB
time = 1

[Command]
name = "holdup" ;Required (do not remove)
command = /$U
time = 1

[Command]
name = "holdupfwd"
command = /$UF
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1, Label]           ;Change Label to any name you want to use to
;                               ;identify the state with.
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = command_name
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, air)
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in.


; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]

;===========================================================================
;Alternate States

;===========================================================================
;Super Attacks

;---------------------------------------------------------------------------
; Hypercane 3-Pack

[State -1, Hypercane 3-Pack]
type = ChangeState
value = 3100
trigger1 = command = "Hypercane_3-Pack"
trigger1 = power >= 1000 ;1000 energy points (one stock) are required
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy

; (Super cancel transition)
[State -1, Hypercane 3-Pack]
type = ChangeState
value = 3100
trigger1 = command = "Hypercane_3-Pack"
trigger1 = power >= 1000 ;1000 energy points (one stock) are required
trigger1 = statetype = S
trigger1 = stateno = 811 ;Creamy must be in state 811 (HP grab combo)
trigger1 = AnimElemNo(0) >= 8 ;move must be completed on or after eighth frame
trigger1 = AnimElemNo(0) <= 9 ;move must be completed on or before ninth frame
trigger1 = RoundState = 2 ;players are currently in battle

; (Super cancel transition)
[State -1, Hypercane 3-Pack]
type = ChangeState
value = 3100
trigger1 = command = "Hypercane_3-Pack"
trigger1 = power >= 1000 ;1000 energy points (one stock) are required
trigger1 = statetype = S
trigger1 = stateno = 821 ;Creamy must be in state 811 (HP grab combo)
trigger1 = AnimElemNo(0) >= 10 ;move must be completed or after tenth frame
trigger1 = AnimElemNo(0) <= 11 ;move must be completed on before eleventh frame
trigger1 = RoundState = 2 ;players are currently in battle

;---------------------------------------------------------------------------
; Atomic Fireball - QP

[State -1, Atomic Fireball - QP]
type = ChangeState
value = 3200
trigger1 = command = "Atomic_Fireball_-_QP"
trigger1 = power >= 1000 ;1000 energy points (one stock) are required
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Atomic Fireball - HP

[State -1, Atomic Fireball - HP]
type = ChangeState
value = 3300
trigger1 = command = "Atomic_Fireball_-_HP"
trigger1 = power >= 2000 ;2000 energy points (two stocks) are required
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Twizzler Downpour

[State -1, Twizzler Downpour]
type = ChangeState
value = 3400
trigger1 = command = "Twizzler_Downpour"
trigger1 = power >= 2000 ;2000 energy points (two stocks) are required
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy

;===========================================================================
;EX Attacks

;---------------------------------------------------------------------------
; Sure You Cane - EX

[State -1, Sure You Cane - EX]
type = ChangeState
value = 420
trigger1 = command = "Sure_You_Cane_-_EX"
trigger1 = power >= 500 ;500 energy points (half stock) are required
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy

;----------

; (Combo transition)
[State -1, Sure You Cane - EX]
type = ChangeState
value = 428 ;switches to State 428 (Sure You Cane - EX - Combo transition)
triggerall = command = "Sure_You_Cane_-_EX"
trigger1 = power >= 500 ;500 energy points (half stock) are required
trigger1 = statetype = S
trigger1 = stateno = 256 ;Creamy must be in state 256 (Short range uppercut)
trigger1 = AnimElemNo(0) = [5, 7] ;move must be between the sixth and seventh frames

;---------------------------------------------------------------------------
; Pez Machine-Gun - EX

[State -1, Pez Machine-Gun - EX]
type = ChangeState
value = 410
trigger1 = command = "Pez_Machine-Gun_-_EX"
trigger1 = power >= 500 ;500 energy points (half stock) are required
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy
trigger1 = NumProjID(711) = 0 ;no Pez Machine-Gun projectiles exist

;===========================================================================
;Special Attacks

;---------------------------------------------------------------------------
; Sure You Cane - QP

[State -1, Sure You Cane - QP]
type = ChangeState
value = 350
trigger1 = command = "Sure_You_Cane_-_QP"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy

;----------

; (Combo transition)
[State -1, Sure You Cane - QP]
type = ChangeState
value = 358 ;switches to State 358 (Sure You Cane - QP - Combo transition)
triggerall = command = "Sure_You_Cane_-_QP"
trigger1 = power >= 500 ;500 energy points (half stock) are required
trigger1 = statetype = S
trigger1 = stateno = 256 ;Creamy must be in state 256 (Short range uppercut)
trigger1 = AnimElemNo(0) = [5, 7] ;move must be between the sixth and seventh frames

;---------------------------------------------------------------------------
; Sure You Cane - HP

[State -1, Sure You Cane - HP]
type = ChangeState
value = 360
trigger1 = command = "Sure_You_Cane_-_HP"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Pixie Stick Stunner

[State -1, Pixie Stick Stunner]
type = ChangeState
value = 370
trigger1 = command = "Pixie_Stick_Stunner"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy
trigger1 = p2stateno != 375
;^(opponent is not already dizzy by Pixie Stick Stunner)^


;---------------------------------------------------------------------------
; Pez Machine-Gun - QP

[State -1, Pez Machine-Gun - QP]
type = ChangeState
value = 310
trigger1 = command = "Pez_Machine-Gun_-_QP"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy
trigger1 = NumProjID(711) = 0 ;no Pez Machine-Gun projectiles exist

;---------------------------------------------------------------------------
; Pez Machine-Gun - HP

[State -1, Pez Machine-Gun - HP]
type = ChangeState
value = 320
trigger1 = command = "Pez_Machine-Gun_-_HP"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy
trigger1 = NumProjID(711) = 0 ;no Pez Machine-Gun projectiles exist

;---------------------------------------------------------------------------
; Lemon Warhead - QP

[State -1, Lemon Warhead - QP]
type = ChangeState
value = 330
trigger1 = command = "Lemon_Warhead_-_QP"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Lemon Warhead - HP

[State -1, Lemon Warhead - HP]
type = ChangeState
value = 340
trigger1 = command = "Lemon_Warhead_-_HP"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy

;===========================================================================
;Special Techniques

;---------------------------------------------------------------------------
; Run Forward

[State -1, Run Fwd]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Hop Backward

[State -1, Run Back]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Power Charge

[State -1, Power Charge]
type = ChangeState
value = 160
triggerall = command = "c"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy
trigger1 = power < 3000 ;Creamy must have less than 3000 points of energy

;---------------------------------------------------------------------------
; Dodge

[State -1, Dodge]
type = ChangeState
value = 501
triggerall = command = "z"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Parry High

;[State -1, Parry High]
;type = HitOverride
;triggerall = command = "fwd"
;triggerall = statetype = S ;can't parry in the air
;trigger1 = stateno != 3100
;trigger1 = ctrl = 1 ;player must be in control of {char. name}
;trigger2 = stateno = 508 ;State 508 (Parry High)
;attr = SA, AA, AP ;standing and aerial, all hit attacks, all projectiles
;stateno = 508 ;switches to State 508 (Parry High)
;time = # ;parry timing window

;---------------------------------------------------------------------------
; Parry Low

;[State -1, Parry Low]
;type = HitOverride
;triggerall = command = "downfwd"
;triggerall = statetype = S ;can't parry in the air
;trigger1 = ctrl = 1 ;player must be in control of {char. name}
;trigger2 = stateno = 509 ;State 509 (Parry Low)
;attr = C, AA, AP ;crouching, all hit attacks, all projectiles
;stateno = 509 ;switches to State 509 (Parry Low)
;time = # ;parry timing window

;---------------------------------------------------------------------------
; Parry Inhibitor

;[State -1, Parry Inhibitor]
;type = HitOverride
;triggerall = ctrl = 0 ;player must not be in control of {char. name}
;trigger1 = stateno = 3100 ;State 3100 (Oteigh Drop - Attempt)
;trigger2 = stateno = 320 ;State 320 (Ura Nage - Attempt)
;attr = SA, AA, AP ;standing and aerial, all hit attacks, all projectiles
;stateno = -1 ;state does not change
;time = 0 ;parry timing window

;---------------------------------------------------------------------------
; Breakout Burst

;[State -1, Breakout Burst]
;type = ChangeState
;value = 511 ;switches to State 511 (Breakout Burst)
;triggerall = command = "Breakout_Burst"
;trigger1 = P2BodyDist X <= 30 ;must be 30 pixels away from opponent or closer
;trigger1 = stateno = 150 ;{char. name} must be in state 150 (Block)

;===========================================================================
;Combo Attacks

;---------------------------------------------------------------------------
; Second quick jab

[State -1, Second quick jab]
type = ChangeState
value = 251
trigger1 = command = "x"
trigger1 = statetype = S
trigger1 = stateno = 201 ;Creamy must be in state 201 (Standing quick jab)
trigger1 = AnimElemNo(0) = 2 ;move must be completed on second frame

;---------------------------------------------------------------------------
; Long range uppercut

[State -1, Long range uppercut]
type = ChangeState
value = 252
trigger1 = command = "y"
trigger1 = statetype = S
trigger1 = stateno = 251 ;Creamy must be in state 251 (Second quick jab)
trigger1 = AnimElemNo(0) = 3 ;move must be completed on third frame

;---------------------------------------------------------------------------
; Hard hook

[State -1, Hard hook]
type = ChangeState
value = 253
trigger1 = command = "y"
trigger1 = statetype = S
trigger1 = stateno = 201 ;Creamy must be in state 201 (Standing quick jab)
trigger1 = AnimElemNo(0) = 2 ;move must be completed on second frame

;---------------------------------------------------------------------------
; Hard elbow smash 2

[State -1, Hard elbow smash 2]
type = ChangeState
value = 254
trigger1 = command = "y"
trigger1 = statetype = S
trigger1 = stateno = 253 ;Creamy must be in state 253 (Hard hook)
trigger1 = AnimElemNo(0) = 4 ;move must be completed on fourth frame

;---------------------------------------------------------------------------
; Upwards forearm smash

[State -1, Upwards forearm smash]
type = ChangeState
value = 255
trigger1 = command = "x"
trigger1 = statetype = S
trigger1 = stateno = 254 ;Creamy must be in state 254 (Hard elbow smash 2)
trigger1 = AnimElemNo(0) = [3, 5] ;move must be completed between the third and fifth frames

;---------------------------------------------------------------------------
; Short range uppercut

[State -1, Short range uppercut]
type = ChangeState
value = 256
trigger1 = command = "y"
trigger1 = statetype = S
trigger1 = stateno = 255 ;Creamy must be in state 255 (Upwards forearm smash)
trigger1 = AnimElemNo(0) = [2, 3] ;move must be between the second and third frames

;===========================================================================
;Standard Attacks

;---------------------------------------------------------------------------
; Quick elbow smash

[State -1, Quick elbow smash]
type = ChangeState
value = 217
triggerall = command = "x"
trigger1 = statetype = S
trigger1 = p2bodydist X < 3 ;must be closer than three pixels from opponent
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; HP grab combo

[State -1, HP grab combo]
type = ChangeState
value = 218 ;switches to State 218 (HP grab combo)
triggerall = command = "fwd_y"
trigger1 = statetype = S ;must be standing on the ground
trigger1 = p2bodydist X < 20 ;must be closer than twenty pixels from opponent
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Quick knee smash

[State -1, Quick knee smash]
type = ChangeState
value = 219
triggerall = command = "a"
trigger1 = statetype = S
trigger1 = p2bodydist X < 5 ;must be closer than five pixels from opponent
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; HK grab combo

[State -1, HK grab combo]
type = ChangeState
value = 220 ;switches to State 218 (HK grab combo)
triggerall = command = "fwd_b"
trigger1 = statetype = S ;must be standing on the ground
trigger1 = p2bodydist X < 20 ;must be closer than twenty pixels from opponent
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; High candy cane thrust

[State -1, High candy cane thrust]
type = ChangeState
value = 241
trigger1 = command = "x"
trigger1 = statetype = S
trigger1 = stateno = 100
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Candy cane jumpslash

[State -1, Candy cane jumpslash]
type = ChangeState
value = 242
trigger1 = command = "y"
trigger1 = statetype = S
trigger1 = stateno = 100
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Flying knee smash

[State -1, Flying knee smash]
type = ChangeState
value = 243
trigger1 = command = "a"
trigger1 = statetype = S
trigger1 = stateno = 100
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Power slide

[State -1, Power slide]
type = ChangeState
value = 244
trigger1 = command = "b"
trigger1 = statetype = S
trigger1 = stateno = 100
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Standing quick jab

[State -1, Standing quick jab]
type = ChangeState
value = 201
trigger1 = command = "x"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Hard elbow smash 1

[State -1, Hard elbow smash 1]
type = ChangeState
value = 202
trigger1 = command = "y"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Quick low side kick

[State -1, Quick low side kick]
type = ChangeState
value = 203
trigger1 = command = "a"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Hard roundhouse kick

[State -1, Hard roundhouse kick]
type = ChangeState
value = 204
trigger1 = command = "b"
trigger1 = statetype = S
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Crouching quick jab

[State -1, Crouching quick jab]
type = ChangeState
value = 213
trigger1 = command = "x"
trigger1 = statetype = C
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Hard uppercut

[State -1, Hard uppercut]
type = ChangeState
value = 214
trigger1 = command = "y"
trigger1 = statetype = C
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Quick ground kick

[State -1, Quick ground kick]
type = ChangeState
value = 215
trigger1 = command = "a"
trigger1 = statetype = C
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Foot sweep

[State -1, Foot sweep]
type = ChangeState
value = 216
trigger1 = command = "b"
trigger1 = statetype = C
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Pogo Bounce

[State -1, Pogo Bounce]
type = ChangeState
value = 221
trigger1 = command = "x"
trigger1 = statetype = A
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Candy cane backswing

[State -1, Candy cane backswing]
type = ChangeState
value = 222
trigger1 = command = "y"
trigger1 = statetype = A
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Aerial quick kick

[State -1, Aerial quick kick]
type = ChangeState
value = 223
trigger1 = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1 ;player must be in control of Creamy

;---------------------------------------------------------------------------
; Back spin kick

[State -1, Back spin kick]
type = ChangeState
value = 224
trigger1 = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1 ;player must be in control of Creamy
